<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Startup</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Enable Splash Screen</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ekran powitalny</translation>
    </message>
</context>
<context>
    <name>StartupPreferences</name>
    <message>
        <location filename="../StartupPreferences.js" line="+24"/>
        <source>Startup</source>
        <translatorcomment>--google--
Pokazuj to okno przy uruchamianiu</translatorcomment>
        <translation>Uruchamianie</translation>
    </message>
</context>
</TS>
